@@ -1,10 +1,10 @@
 from .abs_source import AbsSource
-from .data_source_loc import DataSourceLoc
 from. data_sources import DataSources
 from .df_processor import DFProcessor
 from .file_source import FileSource, FileExtensions
 from .source_manager import SourceManager
 from .table_source import TableSource
 from .excel import ExcelSource
+from .web_scrape import WebSource
 
-__all__ = ["ExcelSource", "sharepoint", "sql", "web_scrape", "AbsSource", "DataSourceLoc", "DataSources", "DFProcessor", "FileSource", "FileExtensions", "SourceManager", "TableSource"]
+__all__ = ["ExcelSource", "sharepoint", "sql", "web_scrape", "AbsSource", "DataSources", "DFProcessor", "FileSource", "FileExtensions", "SourceManager", "TableSource", "WebSource"]
