@@ -12,6 +12,19 @@ class FileExtensions(enum.Enum):
 
 # FileSource: Class for a source from a file
 class FileSource(AbsSource):
+    """
+    This Class inherits from :class:`~Reporter.data_sources.abs_source.AbsSource`
+    
+
+    A data source for importing raw data from a file location
+
+    Attributes
+    ----------
+    post_processor: Optional[:class:`~Reporter.data_sources.df_processor.DFProcessor`]
+        the procesor used to transform the imported raw table from the source
+
+        **Default**: ``None``
+    """
     def __init__(self, path: str, post_processor: Optional[DFProcessor] = None):
         super().__init__(post_processor)
         self._path = path
@@ -20,12 +33,20 @@ class FileSource(AbsSource):
     # path(): Getter for 'path'
     @property
     def path(self):
+        """
+            The file path to the data source
+
+                **Type:** :class:`str`
+        """
         return self._path
 
 
     # path(): Setter to check if 'new_path' exists
     @path.setter
     def path(self, new_path: str):
+        """
+        setting a new file path to the data source
+        """
         glob_result = glob.glob(new_path)
 
         # get the latest file if we have multiple files that match the globbing result
