@@ -6,6 +6,15 @@ from .sql_conn import SQLConn
 # ODBCConn: Wrapper to deal with ODBC connections
 # Note: This is for a very basic ODBC connection
 class ODBCConn(SQLConn):
+    """
+    A very basic ODBC connection assuming it only requires the dsn name
+
+    Attributes
+    ----------
+    dsn_name: :class:`str`
+        The name of the data source to connect to
+    """
+
     def __init__(self, dsn_name: str):
         self.dsn = dsn_name
         super().__init__()
