@@ -2,6 +2,16 @@ from typing import Optional
 
 
 class AbsException(Exception):
+    """
+    This Class inherits from :class:`Exception`
+
+    The base exception the API
+
+    Attributes
+    ----------
+    message: Optional[:class:`str`]
+        the error message to be sent
+    """
     def __init__(self, message: Optional[str] = None, *args, **kwargs):
         self.message = message
         self.args = args
