@@ -4,6 +4,19 @@ from typing import Optional
 
 # NonExistentFileError: Exception if a file does not exists
 class NonExistentFileError(AbsException):
+    """
+    This Class inherits from :class:`~Reporter.exceptions.abs_except.AbsException`
+
+    Exception thrown when a file does not exists
+
+    Attributes
+    ----------
+    filename: :class:`str`
+        The name of the file that was searched
+
+    message: Optional[:class:`str`]
+        a specific message to overwrite the default message template of this exception
+    """
     def __init__(self, filename: str, message: Optional[str] = None, *args, **kwargs):
         super().__init__(message)
         self.filename = filename
