@@ -1,10 +1,7 @@
+from .observers import *
 from .subject import Subject
 from .export import ExportSubject
 from .progress import ProgressSubject
 from .report import ReportSubject
-from .observers.observer import Observer
-from .observers.excel_observer import ExcelObserver
-from .observers.excel_export_observer import ExcelExportObserver
-from .observers.prog_text_observer import ProgTextObserver
 
 __all__ = ["observers", "Subject", "ExportSubject", "ProgressSubject", "ReportSubject", "Observer", "ExcelObserver", "ProgTextObserver", "ExcelExportObserver"]
